<?php # $Id: lang_bg.inc.php 2044 2007-12-01 08:46:08Z jwalker $

/**
 *  @version $Revision: 2044 $
 *  @author Ivan Cenov jwalker@hotmail.bg
*  EN-Revision: 2030
 */

    @define('PLUGIN_EVENT_MAILER_NAME', '    e-mail');
    @define('PLUGIN_EVENT_MAILER_DESC', '       e-mail    .');
    @define('PLUGIN_EVENT_MAILER_RECIPIENT', '');
    @define('PLUGIN_EVENT_MAILER_RECIPIENTDESC', 'E-mail ,      (:  ).');
    @define('PLUGIN_EVENT_MAILER_LINK', '     ?');
    @define('PLUGIN_EVENT_MAILER_LINKDESC', '  \'\'         .');
    @define('PLUGIN_EVENT_MAILER_STRIPTAGS', '  HTML?');
    @define('PLUGIN_EVENT_MAILER_STRIPTAGSDESC', '  \'\' HTML         .');
    @define('PLUGIN_EVENT_MAILER_CONVERTP', '  HTML     ?');
    @define('PLUGIN_EVENT_MAILER_CONVERTPDESC', '  \'\'      HTML .          HTML,         .');
    @define('PLUGIN_EVENT_MAILER_RECIPIENTS', ' (      )');
    @define('PLUGIN_EVENT_MAILER_NOTSENDDECISION', '     e-mail,     .');
    @define('PLUGIN_EVENT_MAILER_SENDING', '');
    @define('PLUGIN_EVENT_MAILER_ISTOSENDIT', '     e-mail');
    @define('PLUGIN_EVENT_MAILER_SENDTOALL', '   ');
